import { Component } from "@angular/core";
import { NavController, NavParams, ActionSheetController, AlertController } from "ionic-angular";

import { BaseListView } from "../../base/base-list-view";
import { Partner } from "../../odoo/models/res.partner";
import { CustomerPage } from "../customer/customer";

@Component({
    selector: 'page-customers',
    templateUrl: 'customers.html'
})
export class CustomersPage extends BaseListView<Partner> {

    constructor(
        public navCtrl: NavController,
        public navParams: NavParams,
        public actionSheetCtrl: ActionSheetController,
        public alertController: AlertController
    ) {
        super(Partner, ["customer", "=", true]);
     }

    ionViewDidLoad() {
        console.log('ionViewDidLoad CustomersPage');
    }

    /**
     * 
     * @param item
     */
    openOptions(item: Partner): void {
        this.setSelectedItem(item);
        
        this.actionSheetCtrl.create({
            title: "Opciones",
            buttons: [
                {
                    text: "Abrir",
                    icon: "open",
                    handler: () => {
                        this.goToDetails();
                    }
                },
                {
                    text: "Ir a ubicación",
                    icon: "navigate",
                    handler: () => {

                    }
                },
                {
                    text: "Llamar",
                    icon: "call",
                    handler: () => {

                    }
                },
                {
                    text: "Eliminar",
                    icon: "close",
                    role: "destructive",
                    handler: () => {
                        this.askIfDelete();
                    }
                },
                {
                    text: "Cancel",
                    role: "cancel",
                    handler: () => {
                        console.log("Canceled");
                        
                    }
                },
            ]
        }).present();
    }

    /**
     * 
     */
    goToDetails(): void {
        this.navCtrl.push(CustomerPage, super.getSelectedItem());
    }

    /**
     * 
     */
    askIfDelete(): void {
        this.alertController.create({
            title: "Confirmar",
            message: "Quieres eliminar este cliente?",
            buttons: [
                {
                    text: "Cancelar"
                },
                {
                    text: "Aceptar",
                    handler: () => {
                        super.performDelete().subscribe(result => console.log(result), error => console.log(error));
                    }
                }
            ]
        }).present();
    }
}
